summaryrefslogtreecommitdiffstats
path: root/libhb/common.h
diff options
context:
space:
mode:
authorjstebbins <[email protected]>2011-06-12 18:05:20 +0000
committerjstebbins <[email protected]>2011-06-12 18:05:20 +0000
commit991912416a55dfcf100591f31e6e72f3f2f5275d (patch)
tree0ed644ee9ba9d05e20e30de2a0805aa27802405c /libhb/common.h
parente36c5d5cc69a207b088a0c92c8c6cb7a3f50ba21 (diff)
libhb: generalize channel remapping between decoders and encoders
Decoders set the channel map of their output in hb_audio_config_t. Encoders use this information to remap while encoding. git-svn-id: svn://svn.handbrake.fr/HandBrake/trunk@4052 b64f7644-9d1e-0410-96f1-a4d463321fa5
Diffstat (limited to 'libhb/common.h')
-rw-r--r--libhb/common.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/libhb/common.h b/libhb/common.h
index ee3bc3b98..492e39750 100644
--- a/libhb/common.h
+++ b/libhb/common.h
@@ -82,6 +82,7 @@ typedef struct hb_lock_s hb_lock_t;
#else
#define PRIVATE const
#endif
+#include "downmix.h"
hb_list_t * hb_list_init();
int hb_list_count( hb_list_t * );
@@ -423,10 +424,9 @@ struct hb_audio_config_s
PRIVATE uint32_t mode; /* Bitstream mode, codec dependent encoding */
PRIVATE int samplerate; /* Input sample rate (Hz) */
PRIVATE int bitrate; /* Input bitrate (kbps) */
- PRIVATE int channel_layout;
- /* channel_layout is the channel layout of this audio this is used to
- * provide a common way of describing the source audio
- */
+ PRIVATE int channel_layout; /* channel_layout is the channel layout of this audio this is used to
+ * provide a common way of describing the source audio */
+ PRIVATE hb_chan_map_t * channel_map; /* source channel map, set by the audio decoder */
} in;
/* Misc. */
@@ -715,6 +715,7 @@ typedef struct hb_work_info_s
};
struct { // info only valid for audio decoders
int channel_layout;
+ hb_chan_map_t * channel_map;
};
};
} hb_work_info_t;